[orca] Fix for bgo#617976 - OO spreadsheet should present the equation on the braille display when pressing
- From: Mesar Hameed <mhameed src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [orca] Fix for bgo#617976 - OO spreadsheet should present the equation on the braille display when pressing
- Date: Thu, 6 May 2010 23:48:54 +0000 (UTC)
commit 75d7b5c7cd718e4e28048eab71b14a50bf94457f
Author: Mesar Hameed <mhameed src gnome org>
Date: Fri May 7 00:47:38 2010 +0100
Fix for bgo#617976 - OO spreadsheet should present the equation on the braille display when pressing orca+a
src/orca/scripts/apps/soffice/script.py | 14 ++++++++------
1 files changed, 8 insertions(+), 6 deletions(-)
---
diff --git a/src/orca/scripts/apps/soffice/script.py b/src/orca/scripts/apps/soffice/script.py
index a5b8b24..9de9e14 100644
--- a/src/orca/scripts/apps/soffice/script.py
+++ b/src/orca/scripts/apps/soffice/script.py
@@ -225,13 +225,13 @@ class Script(default.Script):
self.inputEventHandlers.update(\
self.structuralNavigation.inputEventHandlers)
- self.inputEventHandlers["speakInputLineHandler"] = \
+ self.inputEventHandlers["presentInputLineHandler"] = \
input_event.InputEventHandler(
- Script.speakInputLine,
+ Script.presentInputLine,
# Translators: this is the input line of a spreadsheet
# (i.e., the place where enter formulas)
#
- _("Speaks the contents of the input line."))
+ _("Presents the contents of the input line."))
self.inputEventHandlers["setDynamicColumnHeadersHandler"] = \
input_event.InputEventHandler(
@@ -281,7 +281,7 @@ class Script(default.Script):
"a",
settings.defaultModifierMask,
settings.ORCA_MODIFIER_MASK,
- self.inputEventHandlers["speakInputLineHandler"]))
+ self.inputEventHandlers["presentInputLineHandler"]))
keyBindings.add(
keybindings.KeyBinding(
@@ -929,8 +929,8 @@ class Script(default.Script):
return True
- def speakInputLine(self, inputEvent):
- """Speak the contents of the spread sheet input line (assuming we
+ def presentInputLine(self, inputEvent):
+ """Presents the contents of the spread sheet input line (assuming we
have a handle to it - generated when we first focus on a spread
sheet table cell.
@@ -956,6 +956,8 @@ class Script(default.Script):
inputLine = _("empty")
debug.println(self.debugLevel,
"StarOffice.speakInputLine: contents: %s" % inputLine)
+ self.displayBrailleMessage(inputLine, \
+ flashTime=settings.brailleFlashTime)
speech.speak(inputLine)
except NotImplementedError:
pass
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]